@@ -6,10 +6,10 @@ from azureml.core.compute import ComputeTarget, AmlCompute
 import click, os, time, re
 from azureml_ngc_tools.AzureMLComputeCluster import AzureMLComputeCluster
 from azureml_ngc_tools.cli import ngccontent
-from azureml_ngc_tools.cli import azcli_utils
+#from azureml_ngc_tools.cli import azcli_utils
 from azureml.exceptions._azureml_exception import ProjectSystemException
-from dask_cloudprovider.azure import AzureVMCluster
-from dask.distributed import Client
+#from dask_cloudprovider.azure import AzureVMCluster
+#from dask.distributed import Client
 
 ### SETUP LOGGING
 fileFormatter = logging.Formatter("%(asctime)s [%(levelname)-5.10s]  %(message)s")
@@ -42,28 +42,29 @@ def start(login, app):
     gpus_per_node = validateVMSize(ws,login_config,logger)
 
     useDask = figureDaskUsage(login_config)
-    
-    if (not useDask):
-        ct, pri_key_file = setUpComputeTarget(ws,login_config)
-        env = createOrGetEnvironment(ws, login_config, app_config)
-        cluster, jupyter_link = getAzureMLComputeCluster(ws,ct,env,login_config,pri_key_file)
-    else:
-        azcli_utils.login()
-        log("\nCreating a Dask Cluster with {} nodes".format(login_config["aml_compute"]["max_nodes"]))
-        cluster, jupyter_link, client = getAzureVMCluster(ws,gpus_per_node,login_config,app_config)
-        
-
+    folders = []
     ### UPLOAD ADDITIONAL CONTENT IF NOT EXISTS
     for additional_content in app_config["additional_content"]["list"]:
         url = additional_content["url"]
         targetfile = additional_content["filename"]
         src_path = additional_content["localdirectory"]
         dest_path = additional_content["computedirectory"]
-
         if (useDask):
             load_content_to_scheduler(url,targetfile,src_path,dest_path,additional_content,app_config,client)
         else:
-            load_content(url,targetfile,src_path,dest_path,additional_content,app_config,ws)
+            folder = load_content(url,targetfile,src_path,dest_path,additional_content,app_config,ws)
+            folders.append(folder)
+    
+    log("folders {}".format(" ".join(folders)))
+
+    if (not useDask):
+        ct, pri_key_file = setUpComputeTarget(ws,login_config)
+        env = createOrGetEnvironment(ws, login_config, app_config)
+        cluster, jupyter_link = getAzureMLComputeCluster(ws,ct,env,login_config,pri_key_file,folders)
+    else:
+        azcli_utils.login()
+        log("\nCreating a Dask Cluster with {} nodes".format(login_config["aml_compute"]["max_nodes"]))
+        cluster, jupyter_link, client = getAzureVMCluster(ws,gpus_per_node,login_config,app_config)
     
     if (useDask):
         client.close()
@@ -154,6 +155,7 @@ def getWorkspace(login_config,logger):
         logger.exception(msg)
         raise Exception(msg)
 
+    ws.write_config(path="./", file_name="config.json")
     verify = f"""
     Subscription ID: {subscription_id}
     Resource Group: {resource_group}
@@ -236,7 +238,7 @@ def getAzureVMCluster(ws,gpus_per_node,login_config,app_config):
     jupyter_link = "{}:8888".format(cluster.scheduler_address.split(':')[1].split('//')[1])
     return cluster, jupyter_link, client
 
-def getAzureMLComputeCluster(ws,ct,env,login_config,pri_key_file):
+def getAzureMLComputeCluster(ws,ct,env,login_config,pri_key_file,folders):
     cluster = AzureMLComputeCluster(
         workspace=ws,
         compute_target=ct,
@@ -247,6 +249,7 @@ def getAzureMLComputeCluster(ws,ct,env,login_config,pri_key_file):
         telemetry_opt_out=login_config["azureml_user"]["telemetry_opt_out"],
         admin_username=login_config["aml_compute"]["admin_name"],
         admin_ssh_key=pri_key_file,
+        folders=folders,
         )
     jupyter_link = cluster.jupyter_link
     return cluster, jupyter_link
@@ -392,6 +395,7 @@ def createOrGetEnvironment(ws, login_config, app_config):
         env.docker.base_dockerfile = f'FROM {app_config["base_dockerfile"]}'
         env.python.interpreter_path = python_interpreter
         env.python.user_managed_dependencies = True
+        env.environment_variables = {"AZUREML_COMPUTE_USE_COMMON_RUNTIME":"false"}
         conda_dep = CondaDependencies()
 
         for conda_package in conda_packages:
@@ -407,6 +411,7 @@ def createOrGetEnvironment(ws, login_config, app_config):
 
 def load_content(url,targetfile,src_path,dest_path,additional_content,app_config,ws):
     tarextensions = [".tar",".tbz",".tgz",".txz"]
+    folder = ""
     if app_config["additional_content"]["download_content"]:
         if (
             "source" in additional_content.keys()
@@ -442,8 +447,9 @@ def load_content(url,targetfile,src_path,dest_path,additional_content,app_config
             "additional_content/" + src_path,
             dest_path,
         )
+        folder=dest_path
 
-    return
+    return folder
 
 
 def load_content_to_scheduler(url,targetfile,src_path,dest_path,additional_content,app_config,client):
