@@ -8,12 +8,35 @@ import argparse
 import threading
 import subprocess
 import logging
+import nbformat as nbf
 
 ####---from mpi4py import MPI
+def createCopyDataNotebook(fname,folders):
+    nb = nbf.v4.new_notebook()
+    text = """\
+# Copy Required Data from Datastore."""
+    code1 = """\
+import azureml.core
+from azureml.core import Workspace, Datastore
 
+ws = Workspace.from_config()
+datastore = ws.get_default_datastore()"""
 
-def install(package):
-    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+    code_entries = ["datastore.download('./', '{0}', overwrite=False, show_progress=True)".format(x) for x in folders] 
+    
+    nb['cells'] = [nbf.v4.new_markdown_cell(text),
+               nbf.v4.new_code_cell(code1)]
+    
+    nb['cells'].extend([nbf.v4.new_code_cell(code) for code in code_entries])
+    
+    with open(fname, 'w') as f:
+        nbf.write(nb, f)
+
+def install(package,upgrade=False):
+    if upgrade:
+        subprocess.check_call([sys.executable, "-m", "pip", "install", package,"--upgrade"])
+    else:
+        subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
 
 def flush(proc, proc_log):
@@ -42,11 +65,17 @@ def evaluate_cmd(cmd, logFileName):
     flush(cmd_proc, cmd_log)
     return cmd_proc
 
+def mount(dataset,mnt_root,rel_mnt_path):
+    mounted_path = os.path.join(mnt_root,rel_mnt_path)
+    mount_context = dataset.mount(mounted_path)
+    mount_context.start()
+    return mounted_path
 
 if __name__ == "__main__":
     logger = logging.getLogger(__name__)
     install("azureml-sdk")
     install("notebook")
+
     from azureml.core import Run
     from notebook.notebookapp import list_running_servers
 
@@ -56,7 +85,9 @@ if __name__ == "__main__":
     parser.add_argument("--jupyter_port", default=8888)
     parser.add_argument("--use_gpu", default=False)
     parser.add_argument("--n_gpus_per_node", default=0)
-
+    parser.add_argument('--output_path', dest='output_path', required=True)
+    parser.add_argument('--ws_config', dest='ws_config', required=True)
+    parser.add_argument('--folders', dest='folders', required=True)
     args, unparsed = parser.parse_known_args()
 
     ### CONFIGURE GPU RUN
@@ -98,7 +129,10 @@ if __name__ == "__main__":
     workspace_name = run.experiment.workspace.name.lower()
     run_id = run.get_details()["runId"]
 
-    mount_point = f"/mnt/batch/tasks/shared/LS_root/jobs/{workspace_name}/azureml/{run_id.lower()}/mounts/"
+    #mount_point = f"/mnt/batch/tasks/shared/LS_root/jobs/{workspace_name}/azureml/{run_id.lower()}/mounts/"
+    mount_point = os.path.dirname(args.output_path)
+    os.makedirs(mount_point, exist_ok=True)
+    print("mount_point : " + mount_point)
 
     cmd = (
         f" jupyter lab --ip 0.0.0.0 --port {args.jupyter_port}"
@@ -114,6 +148,20 @@ if __name__ == "__main__":
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
     )
+    
+    f = open(os.path.join(mount_point, "config.json"), "w")
+    f.write(args.ws_config)
+    f.close()
+
+    fname = os.path.join(mount_point, 'CopyData.ipynb')
+    folders = args.folders.split()
+    createCopyDataNotebook(fname,folders)
+    #datastore = run.experiment.workspace.get_default_datastore()
+    #rel_datastore_path = "clara"
+    #datastore_paths = [(datastore, rel_datastore_path)]
+    #dataset = Dataset.File.from_files(path=datastore_paths)
+    #print("Mounting " + rel_datastore_path + " on " + mount_point)
+    #mount(dataset,mount_point,rel_datastore_path)
 
     jupyter_flush = threading.Thread(target=flush, args=(jupyter_proc, jupyter_log))
     jupyter_flush.start()
@@ -126,22 +174,8 @@ if __name__ == "__main__":
 
     flush(jupyter_proc, jupyter_log)
 
-    extraCMDS = {
-        f"wget https://api.ngc.nvidia.com/v2/resources/nvidia/med/getting_started/versions/1/zip": "unload_log.txt",
-        f"mv zip zip.zip": "mv_log.txt",
-        f"unzip zip.zip": "unzip_log.txt",
-    }
-    extraCMDS_procs = {}
-
-    for key in extraCMDS:
-        extraCMDS_procs[key] = evaluate_cmd(key, extraCMDS[key])
-
     if jupyter_proc:
         jupyter_proc.kill()
 
-    for key in extraCMDS_procs:
-        if extraCMDS_procs[key]:
-            extraCMDS_procs[key].kill()
-
     run.complete()
     run.cancel()
